@@ -4,32 +4,19 @@
  *
  * Description : Sane interface for KDE
  *
- * Copyright (C) 2009 by Kare Sars <kare dot sars at iki dot fi>
- * Copyright (C) 2018 by Alexander Volkov <a.volkov@rusbitech.ru>
+ * SPDX-FileCopyrightText: 2009 Kare Sars <kare dot sars at iki dot fi>
+ * SPDX-FileCopyrightText: 2018 Alexander Volkov <a.volkov@rusbitech.ru>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
 
 #include "ksanepreviewimagebuilder.h"
 
-#include <QDebug>
 #include <QImage>
 
+#include <ksane_debug.h>
+
 namespace KSaneIface
 {
 KSanePreviewImageBuilder::KSanePreviewImageBuilder(QImage *img)
@@ -272,7 +259,7 @@ bool KSanePreviewImageBuilder::copyToImage(const SANE_Byte readData[], int read_
         break;
     }
 
-    qWarning() << "Format" << m_params.format
+    qCWarning(KSANE_LOG) << "Format" << m_params.format
                << "and depth" << m_params.depth
                << "is not yet supported by libksane!";
     return false;
