@@ -5,24 +5,10 @@
 * Date        : 2008-11-15
 * Description : Preview image viewer that can handle a selection.
 *
-* Copyright (C) 2008 by Kare Sars <kare dot sars at iki dot fi>
-* Copyright (C) 2014 by Gregor Mitsch: port to KDE5 frameworks
+* SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
+* SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
 *
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Lesser General Public
-* License as published by the Free Software Foundation; either
-* version 2.1 of the License, or (at your option) version 3, or any
-* later version accepted by the membership of KDE e.V. (or its
-* successor approved by the membership of KDE e.V.), which shall
-* act as a proxy defined in Section 6 of version 3 of the license.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 *
 * ============================================================ */
 
@@ -72,6 +58,8 @@ struct KSaneViewer::Private {
     HideRectItem *hideBottom;
     HideRectItem *hideArea;
 
+    bool multiSelectionEnabled = true;
+
     int wheelDelta = 0;
 };
 
@@ -513,6 +501,15 @@ void KSaneViewer::clearSelections()
     updateSelVisibility();
 }
 
+// ------------------------------------------------------------------------
+void KSaneViewer::setMultiselectionEnabled(bool enabled)
+{
+    d->multiSelectionEnabled = enabled;
+    clearSelections();
+    d->selection->setAddButtonEnabled(enabled);
+}
+
+
 // ------------------------------------------------------------------------
 void KSaneViewer::wheelEvent(QWheelEvent *e)
 {
@@ -564,7 +561,7 @@ void KSaneViewer::mouseReleaseEvent(QMouseEvent *e)
     if (e->button() == Qt::LeftButton) {
         if ((d->selection->rect().width() < 0.001) ||
                 (d->selection->rect().height() < 0.001)) {
-            emit newSelection(0.0, 0.0, 1.0, 1.0);
+            Q_EMIT newSelection(0.0, 0.0, 1.0, 1.0);
             clearActiveSelection();
         }
 
@@ -594,7 +591,7 @@ void KSaneViewer::mouseReleaseEvent(QMouseEvent *e)
             d->selectionList.back()->intersects(scenePoint);
 
             // clear the old one
-            emit newSelection(0.0, 0.0, 1.0, 1.0);
+            Q_EMIT newSelection(0.0, 0.0, 1.0, 1.0);
             clearActiveSelection();
         }
     }
@@ -608,7 +605,7 @@ void KSaneViewer::mouseReleaseEvent(QMouseEvent *e)
         float brx = d->selection->rect().right()  / d->img->width();
         float bry = d->selection->rect().bottom() / d->img->height();
 
-        emit newSelection(tlx, tly, brx, bry);
+        Q_EMIT newSelection(tlx, tly, brx, bry);
     }
     updateHighlight();
     QGraphicsView::mouseReleaseEvent(e);
